        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,10,12,14,17,18,21,22,24,27,28,29,32,33,34,35,37,38,40,45,46,47,50';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 13 <br>1,6,9,13,15,16,20,23,26,31,39,44,49';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 10 <br>8,11,19,25,30,36,41,42,43,48';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,10,12,14,17,18,21,22,24,27,28,29,32,33,34,35,37,38,40,45,46,47,50';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 13 <br>1,6,9,13,15,16,20,23,26,31,39,44,49';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 10 <br>8,11,19,25,30,36,41,42,43,48';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,10,12,14,17,18,21,22,24,27,28,29,32,33,34,35,37,38,40,45,46,47,50';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 13 <br>1,6,9,13,15,16,20,23,26,31,39,44,49';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 10 <br>8,11,19,25,30,36,41,42,43,48';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,10,12,14,17,18,21,22,24,27,28,29,32,33,34,35,37,38,40,45,46,47,50';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 13 <br>1,6,9,13,15,16,20,23,26,31,39,44,49';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 10 <br>8,11,19,25,30,36,41,42,43,48';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,10,12,14,17,18,21,22,24,27,28,29,32,33,34,35,37,38,40,45,46,47,50';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 13 <br>1,6,9,13,15,16,20,23,26,31,39,44,49';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 10 <br>8,11,19,25,30,36,41,42,43,48';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>40</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,10,12,14,17,18,21,22,24,27,28,29,32,33,34,35,37,38,40,45,46,47,50';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 13 <br>1,6,9,13,15,16,20,23,26,31,39,44,49';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>19</strong> miembros: 10 <br>8,11,19,25,30,36,41,42,43,48';}
}
